rich_aggregate: aggregate enriched data

Description Usage Arguments Value

View source: R/rich_utils.R

Description

The function looks recursively inside a folder and extract and bind together enrichment data ('report.*.tsv') generated by gsea. If not path is specified it opens an interactive 'svDialogs' modal dialog box to chose the folder.

Usage

1
rich_aggregate(path = svDialogs::dlg_dir()$res)

Arguments

path

The folder to look into, default is 'svDialogs::dlg_dir()$res'

Value

A dataframe of enriched results.


c1au6i0/richcleaner documentation built on Dec. 31, 2020, 9:01 p.m.