rich_pheatmap: rich_pheatmap

Description Usage Arguments

View source: R/richer_graphs.R

Description

Just a wrapper that runs rich_wider and produces a heatmap of the results using 'pheatmap'.

Usage

1
2
3
4
5
6
7
8
9
rich_pheatmap(
  dat,
  fdr_threshold,
  gs,
  value = "n_logp_sign",
  col = c("#053061", "#2166AC", "#4393C3", "#92C5DE", "#D1E5F0", "#F7F7F7", "#FDDBC7",
    "#F4A582", "#D6604D", "#B2182B", "#67001F"),
  ...
)

Arguments

dat

Dataframe as returned by script.

fdr_threshold

Minimum 'FDR.q.val' to keep.

gs

Gene Set.

value

Column from which to take the value for pivit wider. One of c("fdr_q_val", "nes", "nom_p_val", "n_logp_sign"). Defaut is "n_logp_sign".

col

Palette of heatmap. Default is 'rev(RColorBrewer::brewer.pal(11, "RdBu"))'.

...

pheatmap arguments .


c1au6i0/richcleaner documentation built on Dec. 31, 2020, 9:01 p.m.