Description Usage Arguments Value
The function looks recursively inside a folder and extract and bind together enrichment data ('report.*.tsv') generated by gsea. If not path is specified it opens an interactive 'svDialogs' modal dialog box to chose the folder.
1 | rich_aggregate(path = svDialogs::dlg_dir()$res)
|
path |
The folder to look into, default is 'svDialogs::dlg_dir()$res' |
A dataframe of enriched results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.