Given a dataframe generate by rich_aggregate, filters it to get a specific 'gs', it calculates
negative 'log10(p.norm) * sign of NES', filters out all 'FDR.q.val > fdr_threshold' and
returns a wider datagrame with 'pathways' as rows, 'contrasts' as
column and one of the columns as the 'value'. When a combination of contrast-pathway is not presence a 0 is substituted
to NA when pivoting.
1 | rich_wider(dat, fdr_threshold, gs, value = "n_logp_sign")
|
dat |
Dataframe as returned by |
fdr_threshold |
Minimum 'FDR.q.val' to keep. |
gs |
Gene Set Database. |
value |
Column from which to take the value for pivit wider. One of c("fdr_q_val", "nes", "nom_p_val", "n_logp_sign"). Defaut is "n_logp_sign". |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.